pub trait Mapper {
// Provided methods
fn setup(&mut self, _ctx: &mut Context) { ... }
fn map(&mut self, key: usize, value: &[u8], ctx: &mut Context) { ... }
fn cleanup(&mut self, _ctx: &mut Context) { ... }
}Expand description
Trait to represent the mapping stage of MapReduce.
All trait methods have sane defaults to match the Hadoop MapReduce implementation, allowing the developer to pick and choose what they customize without having to write a large amount of boilerplate.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".